#!/usr/bin/python
# -*- coding: utf-8 -*-

# speed test file for YADE
# if you find a mistake within the script, please report to:
# jakob@ifgt.tu-freiberg.de   Thank you!

num_balls1D = 10
num_balls = num_balls1D*num_balls1D*num_balls1D
logfilename = 'speed-test-output%i-balls.log' % (int(num_balls))
origin_wall = num_balls1D/2
x_pos = 0
y_pos = 0
z_pos = 0
friction=0.5
angle=atan(friction)

id_FacetMat=O.materials.append(ViscElMat(kn=1e8,ks=1e8,cn=0.0,cs=0.0,frictionAngle=angle))
id_SphereMat=O.materials.append(ViscElMat(kn=1e6,ks=1e6,cn=0.0,cs=0.0,density=1000,frictionAngle=angle))

FacetMat=O.materials[id_FacetMat]
SphereMat=O.materials[id_SphereMat]

O.engines=[
	ForceResetter(),
	InsertionSortCollider([Bo1_Sphere_Aabb(),Bo1_Facet_Aabb()]),
	InteractionLoop(
		[Ig2_Sphere_Sphere_ScGeom6D(),Ig2_Facet_Sphere_ScGeom()],
		[Ip2_ViscElMat_ViscElMat_ViscElPhys()],
		[Law2_ScGeom_ViscElPhys_Basic()],
	),
	GravityEngine(gravity=(0,0,-9.81)),
	NewtonIntegrator(damping=0.7),
]

#id_wall=O.bodies.append(utils.wall([origin_wall,origin_wall,0],axis=2,sense=1))#kn 1e8 ks 1e8 friction 0.5 normal 0.02 0.02 1
#id_facet=O.bodies.append(geom.facetBox((0,0,0),(10,5,0)))
#id_facet=O.bodies.append(utils.facet([(origin_wall-20,origin_wall-20,0),(origin_wall+20,origin_wall-20,0),(0,origin_wall+20,0)], material=FacetMat, color=(1,0,0)))
#id_facet=O.bodies.append(geom.facetPolygon(center=[origin_wall,origin_wall,0],radiusOuter=100,orientation=[(0.02,0.02,1),5],angleRange=-pi))

#rotation quaternion:
orientationFacet = Quaternion(Vector3(.01,.01,1),math.pi)
#create facet:
id_facet=O.bodies.append(geom.facetBox((origin_wall,origin_wall,0),(100,100,0),orientationFacet,material=FacetMat))

for ii in range(1,num_balls1D):
	x_pos = x_pos + 1
	y_pos = 0
	z_pos = 0
	for jj in range(1,num_balls1D):
		y_pos = y_pos + 1
		z_pos = 0
		for kk in range(1,num_balls1D):
			z_pos = z_pos + 1
			O.bodies.append(utils.sphere([x_pos,y_pos,z_pos], material=SphereMat, radius=0.5, wire=False, highlight=False))#, color=(50,50,0)

#from yade import plot
#from yade import qt
#v=qt.View()
#v.viewDir=(.2,-1,3); v.eyePosition=(0,120,50); v.upVector=(-1,0,1); v.axes=True;

from yade import timing
O.timingEnabled=True
O.dt=1e-3

O.saveTmp()

#run 1:
start_time=O.realtime
O.run(10000,True)
stop_time=O.realtime
time_needed=stop_time-start_time

f = open(logfilename, 'w')
f.write('10000 steps: YADE needed %e seconds\n' % time_needed)

#run 2:
O.loadTmp()
start_time=O.realtime
O.run(20000,True)
stop_time=O.realtime
time_needed=stop_time-start_time

f = open(logfilename, 'a')
f.write('20000 steps: YADE needed %e seconds\n' % time_needed)

#run 3:
O.loadTmp()
start_time=O.realtime
O.run(50000,True)
stop_time=O.realtime
time_needed=stop_time-start_time

f = open(logfilename, 'a')
f.write('50000 steps: YADE needed %e seconds\n' % time_needed)

#run 4:
O.loadTmp()
start_time=O.realtime
O.run(100000,True)
stop_time=O.realtime
time_needed=stop_time-start_time

f = open(logfilename, 'a')
f.write('100000 steps: YADE needed %e seconds\n' % time_needed)

f.close()
